summaryrefslogtreecommitdiff
path: root/lisp
diff options
context:
space:
mode:
authorJuanma Barranquero <lekktu@gmail.com>2010-09-14 16:41:53 +0200
committerJuanma Barranquero <lekktu@gmail.com>2010-09-14 16:41:53 +0200
commit6664fc59a8f296117ea98b943f062c0cc0e907c1 (patch)
treeb8e0bf218492291433d00a71122bc8cd2c662ea9 /lisp
parent74769e8b4c73f24e8f3356bd281a56a30000c648 (diff)
parentf3a30a50fab486dcaafb9d897797794fe4c3c4b3 (diff)
downloademacs-6664fc59a8f296117ea98b943f062c0cc0e907c1.tar.gz
Merge changes from emacs-23 branch.
Diffstat (limited to 'lisp')
-rw-r--r--lisp/ChangeLog71
-rw-r--r--lisp/calendar/appt.el15
-rw-r--r--lisp/calendar/diary-lib.el22
-rw-r--r--lisp/emacs-lisp/byte-run.el13
-rw-r--r--lisp/font-lock.el2
-rw-r--r--lisp/menu-bar.el24
-rw-r--r--lisp/progmodes/antlr-mode.el2
-rw-r--r--lisp/repeat.el7
-rw-r--r--lisp/simple.el2
-rw-r--r--lisp/subr.el13
-rw-r--r--lisp/url/ChangeLog12
-rw-r--r--lisp/url/url-cache.el13
-rw-r--r--lisp/url/url-cookie.el36
-rw-r--r--lisp/vc/vc-hg.el8
14 files changed, 172 insertions, 68 deletions
diff --git a/lisp/ChangeLog b/lisp/ChangeLog
index 52ba1f89303..6f80ba5cdc5 100644
--- a/lisp/ChangeLog
+++ b/lisp/ChangeLog
@@ -1,3 +1,72 @@
+2010-09-14 Stefan Monnier <monnier@iro.umontreal.ca>
+
+ * emacs-lisp/byte-run.el (set-advertised-calling-convention):
+ Add `when' argument. Update callers.
+
+ * subr.el (unintern): Declare the obarray arg mandatory.
+
+2010-09-14 Glenn Morris <rgm@gnu.org>
+
+ * calendar/diary-lib.el (diary-list-entries-hook, diary-sort-entries):
+ Doc fixes.
+
+ * calendar/diary-lib.el (diary-included-files): New variable.
+ (diary-list-entries): Maybe initialize diary-included-files.
+ (diary-include-other-diary-files): Append to diary-included-files.
+ * calendar/appt.el (appt-update-list): Also check the members of
+ diary-included-files. (Bug#6999)
+ (appt-check): Doc fix.
+
+2010-09-14 David Reitter <david.reitter@gmail.com>
+
+ * simple.el (line-move-visual): Do not truncate goal column to
+ integer size. (Bug#7020)
+
+2010-09-14 Stefan Monnier <monnier@iro.umontreal.ca>
+
+ * repeat.el (repeat): Allow repeating when the last event is a click.
+ Suggested by Drew Adams (bug#6256).
+
+2010-09-14 Sascha Wilde <wilde@sha-bang.de>
+
+ * vc/vc-hg.el (vc-hg-state,vc-hg-working-revision):
+ Replace setting HGRCPATH to "" by some less invasive --config options.
+
+2010-09-14 Stefan Monnier <monnier@iro.umontreal.ca>
+
+ * font-lock.el (font-lock-beginning-of-syntax-function):
+ Mark as obsolete.
+
+2010-09-14 Glenn Morris <rgm@gnu.org>
+
+ * menu-bar.el (menu-bar-options-save): Fix handling of menu-bar
+ and tool-bar modes. (Bug#6211)
+ (menu-bar-mode): Move setting of standard-value after the
+ minor-mode definition, otherwise it seems to have no effect.
+
+2010-09-14 Masatake YAMATO <yamato@redhat.com>
+
+ * progmodes/antlr-mode.el (antlr-font-lock-additional-keywords):
+ Fix typo. (Bug#6976)
+
+2010-09-14 Vinicius Jose Latorre <viniciusjl@ig.com.br>
+
+ * whitespace.el: Allow cleaning up blanks without blank
+ visualization (Bug#6651). Adjust help window for
+ whitespace-toggle-options (Bug#6479). Allow to use fill-column
+ instead of whitespace-line-column (from EmacsWiki). New version 13.1.
+ (whitespace-style): Add new value 'face. Adjust docstring.
+ (whitespace-space, whitespace-hspace, whitespace-tab):
+ Adjust foreground property face.
+ (whitespace-line-column): Adjust docstring and type declaration.
+ (whitespace-style-value-list, whitespace-toggle-option-alist)
+ (whitespace-help-text): Adjust const initialization.
+ (whitespace-toggle-options, global-whitespace-toggle-options):
+ Adjust docstring.
+ (whitespace-display-window, whitespace-interactive-char)
+ (whitespace-style-face-p, whitespace-color-on): Adjust code.
+ (whitespace-help-scroll): New fun.
+
2010-09-14 Katsumi Yamaoka <yamaoka@jpl.org>
* calendar/time-date.el (format-seconds): Comment fix.
@@ -116,7 +185,7 @@
(tramp-get-remote-readlink, tramp-get-remote-trash)
(tramp-get-remote-id, tramp-get-remote-uid, tramp-get-remote-gid)
(tramp-get-local-uid, tramp-get-local-gid)
- (tramp-get-inline-compress, tramp-get-inline-coding, ): Move to
+ (tramp-get-inline-compress, tramp-get-inline-coding): Move to
tramp-sh.el.
(tramp-methods, tramp-default-method-alist)
(tramp-default-user-alist, tramp-foreign-file-name-handler-alist):
diff --git a/lisp/calendar/diary-lib.el b/lisp/calendar/diary-lib.el
index 39354bd31e3..46926050362 100644
--- a/lisp/calendar/diary-lib.el
+++ b/lisp/calendar/diary-lib.el
@@ -187,11 +187,12 @@ you will probably also want to add `diary-mark-included-diary-files' to
(setq diary-display-function 'diary-fancy-display)
(add-hook 'diary-list-entries-hook 'diary-include-other-diary-files)
- (add-hook 'diary-list-entries-hook 'diary-sort-entries)
+ (add-hook 'diary-list-entries-hook 'diary-sort-entries t)
in your `.emacs' file to cause the fancy diary buffer to be displayed with
diary entries from various included files, each day's entries sorted into
-lexicographic order."
+lexicographic order. Note how the sort function is placed last,
+so that it can sort the entries included from other files."
:type 'hook
:options '(diary-include-other-diary-files diary-sort-entries)
:group 'diary)
@@ -699,6 +700,10 @@ of the appropriate type."
(1+ (calendar-absolute-from-gregorian gdate))))))
(goto-char (point-min)))
+(defvar diary-including) ; dynamically bound in diary-include-other-diary-files
+(defvar diary-included-files nil
+ "List of any diary files included in the last call to `diary-list-entries'.")
+
;; FIXME non-greg and list hooks run same number of times?
(defun diary-list-entries (date number &optional list-only)
"Create and display a buffer containing the relevant lines in `diary-file'.
@@ -743,6 +748,8 @@ LIST-ONLY is non-nil, in which case it just returns the list."
(date-string (calendar-date-string date))
(diary-buffer (find-buffer-visiting diary-file))
diary-entries-list file-glob-attrs)
+ (or (bound-and-true-p diary-including)
+ (setq diary-included-files nil))
(message "Preparing diary...")
(save-current-buffer
(if (not diary-buffer)
@@ -828,11 +835,15 @@ the variable `diary-include-string'."
(let ((diary-file (match-string-no-properties 1))
(diary-list-entries-hook 'diary-include-other-diary-files)
(diary-display-function 'ignore)
+ (diary-including t)
diary-hook diary-list-include-blanks)
(if (file-exists-p diary-file)
(if (file-readable-p diary-file)
(unwind-protect
- (setq diary-entries-list
+ (setq diary-included-files
+ (append diary-included-files
+ (list (expand-file-name diary-file)))
+ diary-entries-list
(append diary-entries-list
(diary-list-entries original-date number)))
(with-current-buffer (find-buffer-visiting diary-file)
@@ -1574,7 +1585,10 @@ be used instead of a colon (:) to separate the hour and minute parts."
(string-lessp ts1 ts2)))))))
(defun diary-sort-entries ()
- "Sort the list of diary entries by time of day."
+ "Sort the list of diary entries by time of day.
+If you add this function to `diary-list-entries-hook', it should
+be the last item in the hook, in case earlier items add diary
+entries, or change the order."
(setq diary-entries-list (sort diary-entries-list 'diary-entry-compare)))
(define-obsolete-function-alias 'sort-diary-entries 'diary-sort-entries "23.1")
diff --git a/lisp/emacs-lisp/byte-run.el b/lisp/emacs-lisp/byte-run.el
index 6ce141eb8e6..0388435dbc2 100644
--- a/lisp/emacs-lisp/byte-run.el
+++ b/lisp/emacs-lisp/byte-run.el
@@ -108,10 +108,11 @@ The return value of this function is not used."
(defvar advertised-signature-table (make-hash-table :test 'eq :weakness 'key))
-(defun set-advertised-calling-convention (function signature)
+(defun set-advertised-calling-convention (function signature when)
"Set the advertised SIGNATURE of FUNCTION.
This will allow the byte-compiler to warn the programmer when she uses
-an obsolete calling convention."
+an obsolete calling convention. WHEN specifies since when the calling
+convention was modified."
(puthash (indirect-function function) signature
advertised-signature-table))
@@ -132,7 +133,7 @@ was first made obsolete, for example a date or a release number."
obsolete-name)
(set-advertised-calling-convention
;; New code should always provide the `when' argument.
- 'make-obsolete '(obsolete-name current-name when))
+ 'make-obsolete '(obsolete-name current-name when) "23.1")
(defmacro define-obsolete-function-alias (obsolete-name current-name
&optional when docstring)
@@ -153,7 +154,7 @@ See the docstrings of `defalias' and `make-obsolete' for more details."
(set-advertised-calling-convention
;; New code should always provide the `when' argument.
'define-obsolete-function-alias
- '(obsolete-name current-name when &optional docstring))
+ '(obsolete-name current-name when &optional docstring) "23.1")
(defun make-obsolete-variable (obsolete-name current-name &optional when)
"Make the byte-compiler warn that OBSOLETE-NAME is obsolete.
@@ -175,7 +176,7 @@ was first made obsolete, for example a date or a release number."
obsolete-name)
(set-advertised-calling-convention
;; New code should always provide the `when' argument.
- 'make-obsolete-variable '(obsolete-name current-name when))
+ 'make-obsolete-variable '(obsolete-name current-name when) "23.1")
(defmacro define-obsolete-variable-alias (obsolete-name current-name
&optional when docstring)
@@ -210,7 +211,7 @@ CURRENT-NAME, if it does not already have them:
(set-advertised-calling-convention
;; New code should always provide the `when' argument.
'define-obsolete-variable-alias
- '(obsolete-name current-name when &optional docstring))
+ '(obsolete-name current-name when &optional docstring) "23.1")
;; FIXME This is only defined in this file because the variable- and
;; function- versions are too. Unlike those two, this one is not used
diff --git a/lisp/font-lock.el b/lisp/font-lock.el
index 92c62010848..6c316f5f958 100644
--- a/lisp/font-lock.el
+++ b/lisp/font-lock.el
@@ -564,6 +564,8 @@ outside of any comment, string, or sexp. This variable is semi-obsolete;
we recommend setting `syntax-begin-function' instead.
This is normally set via `font-lock-defaults'.")
+(make-obsolete-variable 'font-lock-beginning-of-syntax-function
+ 'syntax-begin-function "23.3")
(defvar font-lock-mark-block-function nil
"*Non-nil means use this function to mark a block of text.
diff --git a/lisp/menu-bar.el b/lisp/menu-bar.el
index 6149fea4769..d0a8653f95c 100644
--- a/lisp/menu-bar.el
+++ b/lisp/menu-bar.el
@@ -664,13 +664,23 @@ by \"Save Options\" in Custom buffers.")
;; put on a customized-value property.
(dolist (elt '(line-number-mode column-number-mode size-indication-mode
cua-mode show-paren-mode transient-mark-mode
- blink-cursor-mode display-time-mode display-battery-mode))
+ blink-cursor-mode display-time-mode display-battery-mode
+ ;; These are set by other functions that don't set
+ ;; the customized state. Having them here has the
+ ;; side-effect that turning them off via X
+ ;; resources acts like having customized them, but
+ ;; that seems harmless.
+ menu-bar-mode tool-bar-mode))
+ ;; FIXME ? It's a little annoying that running this command
+ ;; always loads cua-base, paren, time, and battery, even if they
+ ;; have not been customized in any way. (Due to custom-load-symbol.)
(and (customize-mark-to-save elt)
(setq need-save t)))
;; These are set with `customize-set-variable'.
(dolist (elt '(scroll-bar-mode
debug-on-quit debug-on-error
- tooltip-mode menu-bar-mode tool-bar-mode
+ ;; Somehow this works, when tool-bar and menu-bar don't.
+ tooltip-mode
save-place uniquify-buffer-name-style fringe-mode
indicate-empty-lines indicate-buffer-boundaries
case-fold-search font-use-system-font
@@ -2037,6 +2047,16 @@ turn on menu bars; otherwise, turn off menu bars."
(run-with-idle-timer 0 nil 'message
"Menu-bar mode disabled. Use M-x menu-bar-mode to make the menu bar appear.")))
+;;;###autoload
+;; (This does not work right unless it comes after the above definition.)
+;; This comment is taken from tool-bar.el near
+;; (put 'tool-bar-mode ...)
+;; We want to pretend the menu bar by standard is on, as this will make
+;; customize consider disabling the menu bar a customization, and save
+;; that. We could do this for real by setting :init-value above, but
+;; that would overwrite disabling the menu bar from X resources.
+(put 'menu-bar-mode 'standard-value '(t))
+
(defun toggle-menu-bar-mode-from-frame (&optional arg)
"Toggle menu bar on or off, based on the status of the current frame.
See `menu-bar-mode' for more information."
diff --git a/lisp/progmodes/antlr-mode.el b/lisp/progmodes/antlr-mode.el
index 9b24ac7a1f4..742bcf726eb 100644
--- a/lisp/progmodes/antlr-mode.el
+++ b/lisp/progmodes/antlr-mode.el
@@ -951,7 +951,7 @@ group. The string matched by the first group is highlighted with
(3 antlr-keyword-face)
(4 (if (member (match-string 4) '("Lexer" "Parser" "TreeParser"))
antlr-keyword-face
- type-face)))
+ font-lock-type-face)))
(,(lambda (limit)
(antlr-re-search-forward
"\\<\\(header\\|options\\|tokens\\|exception\\|catch\\|returns\\)\\>"
diff --git a/lisp/repeat.el b/lisp/repeat.el
index eddaf4f020e..86484ec68d6 100644
--- a/lisp/repeat.el
+++ b/lisp/repeat.el
@@ -335,7 +335,12 @@ recently executed command not bound to an input event\"."
(setq real-last-command 'repeat)
(setq repeat-undo-count 1)
(unwind-protect
- (while (eq (read-event) repeat-repeat-char)
+ (while (let ((evt (read-event))) ;FIXME: read-key maybe?
+ ;; For clicks, we need to strip the meta-data to
+ ;; check the underlying event name.
+ (eq (or (car-safe evt) evt)
+ (or (car-safe repeat-repeat-char)
+ repeat-repeat-char)))
(repeat repeat-arg))
;; Make sure `repeat-undo-count' is reset.
(setq repeat-undo-count nil))
diff --git a/lisp/simple.el b/lisp/simple.el
index 36931c7777c..1ab737d5ec1 100644
--- a/lisp/simple.el
+++ b/lisp/simple.el
@@ -4343,7 +4343,7 @@ into account variable-width characters and line continuation."
(or (and (= (vertical-motion
(cons (or goal-column
(if (consp temporary-goal-column)
- (truncate (car temporary-goal-column))
+ (car temporary-goal-column)
temporary-goal-column))
arg))
arg)
diff --git a/lisp/subr.el b/lisp/subr.el
index f2c12a736c2..b391f1f0b93 100644
--- a/lisp/subr.el
+++ b/lisp/subr.el
@@ -239,7 +239,7 @@ letter but *do not* end with a period. Please follow this convention
for the sake of consistency."
(while t
(signal 'error (list (apply 'format args)))))
-(set-advertised-calling-convention 'error '(string &rest args))
+(set-advertised-calling-convention 'error '(string &rest args) "23.1")
;; We put this here instead of in frame.el so that it's defined even on
;; systems where frame.el isn't loaded.
@@ -1039,9 +1039,10 @@ is converted into a string by expressing it in decimal."
(make-obsolete 'make-variable-frame-local
"explicitly check for a frame-parameter instead." "22.2")
(make-obsolete 'interactive-p 'called-interactively-p "23.2")
-(set-advertised-calling-convention 'called-interactively-p '(kind))
+(set-advertised-calling-convention 'called-interactively-p '(kind) "23.1")
(set-advertised-calling-convention
- 'all-completions '(string collection &optional predicate))
+ 'all-completions '(string collection &optional predicate) "23.1")
+(set-advertised-calling-convention 'unintern '(name obarray) "23.3")
;;;; Obsolescence declarations for variables, and aliases.
@@ -2064,7 +2065,7 @@ floating point support."
(setq read (cons t read)))
(push read unread-command-events)
nil))))))
-(set-advertised-calling-convention 'sit-for '(seconds &optional nodisp))
+(set-advertised-calling-convention 'sit-for '(seconds &optional nodisp) "22.1")
;;; Atomic change groups.
@@ -2592,7 +2593,7 @@ discouraged."
(start-process name buffer shell-file-name shell-command-switch
(mapconcat 'identity args " ")))
(set-advertised-calling-convention 'start-process-shell-command
- '(name buffer command))
+ '(name buffer command) "23.1")
(defun start-file-process-shell-command (name buffer &rest args)
"Start a program in a subprocess. Return the process object for it.
@@ -2603,7 +2604,7 @@ Similar to `start-process-shell-command', but calls `start-file-process'."
(if (file-remote-p default-directory) "-c" shell-command-switch)
(mapconcat 'identity args " ")))
(set-advertised-calling-convention 'start-file-process-shell-command
- '(name buffer command))
+ '(name buffer command) "23.1")
(defun call-process-shell-command (command &optional infile buffer display
&rest args)
diff --git a/lisp/url/ChangeLog b/lisp/url/ChangeLog
index 170bedd3b28..7726f6cd081 100644
--- a/lisp/url/ChangeLog
+++ b/lisp/url/ChangeLog
@@ -1,3 +1,15 @@
+2010-09-14 Julien Danjou <julien@danjou.info>
+
+ * url-cache (url-store-in-cache): Make `buff' argument really optional.
+
+2010-09-14 Glenn Morris <rgm@gnu.org>
+
+ * url-cookie.el (url-cookie-expired-p): Tweak previous change.
+
+2010-09-14 shawn boles <shawn.boles@gmail.com> (tiny change)
+
+ * url-cookie.el (url-cookie-expired-p): Simplify and fix. (Bug#6957)
+
2010-09-11 Glenn Morris <rgm@gnu.org>
* url-cache.el, url-gw.el, url-history.el, url-irc.el, url-util.el:
diff --git a/lisp/url/url-cache.el b/lisp/url/url-cache.el
index 7cff9aa923d..3a6f00db306 100644
--- a/lisp/url/url-cache.el
+++ b/lisp/url/url-cache.el
@@ -62,14 +62,11 @@ FILE can be created or overwritten."
;;;###autoload
(defun url-store-in-cache (&optional buff)
"Store buffer BUFF in the cache."
- (if (not (and buff (get-buffer buff)))
- nil
- (save-current-buffer
- (and buff (set-buffer buff))
- (let* ((fname (url-cache-create-filename (url-view-url t))))
- (if (url-cache-prepare fname)
- (let ((coding-system-for-write 'binary))
- (write-region (point-min) (point-max) fname nil 5)))))))
+ (with-current-buffer (get-buffer (or buff (current-buffer)))
+ (let ((fname (url-cache-create-filename (url-view-url t))))
+ (if (url-cache-prepare fname)
+ (let ((coding-system-for-write 'binary))
+ (write-region (point-min) (point-max) fname nil 5))))))
;;;###autoload
(defun url-is-cached (url)
diff --git a/lisp/url/url-cookie.el b/lisp/url/url-cookie.el
index 75a1b218830..2067f097224 100644
--- a/lisp/url/url-cookie.el
+++ b/lisp/url/url-cookie.el
@@ -1,7 +1,7 @@
;;; url-cookie.el --- Netscape Cookie support
-;; Copyright (C) 1996, 1997, 1998, 1999, 2004,
-;; 2005, 2006, 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
+;; Copyright (C) 1996, 1997, 1998, 1999, 2004, 2005, 2006, 2007, 2008,
+;; 2009, 2010 Free Software Foundation, Inc.
;; Keywords: comm, data, processes, hypermedia
@@ -24,7 +24,6 @@
;;; Code:
-(require 'timezone)
(require 'url-util)
(require 'url-parse)
(eval-when-compile (require 'cl))
@@ -194,34 +193,9 @@ telling Microsoft that."
(setq url-cookie-storage (list (list domain tmp))))))))
(defun url-cookie-expired-p (cookie)
- (let* (
- (exp (url-cookie-expires cookie))
- (cur-date (and exp (timezone-parse-date (current-time-string))))
- (exp-date (and exp (timezone-parse-date exp)))
- (cur-greg (and cur-date (timezone-absolute-from-gregorian
- (string-to-number (aref cur-date 1))
- (string-to-number (aref cur-date 2))
- (string-to-number (aref cur-date 0)))))
- (exp-greg (and exp (timezone-absolute-from-gregorian
- (string-to-number (aref exp-date 1))
- (string-to-number (aref exp-date 2))
- (string-to-number (aref exp-date 0)))))
- (diff-in-days (and exp (- cur-greg exp-greg)))
- )
- (cond
- ((not exp) nil) ; No expiry == expires at browser quit
- ((< diff-in-days 0) nil) ; Expires sometime after today
- ((> diff-in-days 0) t) ; Expired before today
- (t ; Expires sometime today, check times
- (let* ((cur-time (timezone-parse-time (aref cur-date 3)))
- (exp-time (timezone-parse-time (aref exp-date 3)))
- (cur-norm (+ (* 360 (string-to-number (aref cur-time 2)))
- (* 60 (string-to-number (aref cur-time 1)))
- (* 1 (string-to-number (aref cur-time 0)))))
- (exp-norm (+ (* 360 (string-to-number (aref exp-time 2)))
- (* 60 (string-to-number (aref exp-time 1)))
- (* 1 (string-to-number (aref exp-time 0))))))
- (> (- cur-norm exp-norm) 1))))))
+ "Return non-nil if COOKIE is expired."
+ (let ((exp (url-cookie-expires cookie)))
+ (and exp (> (float-time) (float-time (date-to-time exp))))))
(defun url-cookie-retrieve (host &optional localpart secure)
"Retrieve all the netscape-style cookies for a specified HOST and LOCALPART."
diff --git a/lisp/vc/vc-hg.el b/lisp/vc/vc-hg.el
index c087a4d9e1f..689cd4d12bd 100644
--- a/lisp/vc/vc-hg.el
+++ b/lisp/vc/vc-hg.el
@@ -171,10 +171,12 @@ If nil, use the value of `vc-diff-switches'. If t, use no switches."
(let ((process-environment
;; Avoid localization of messages so we
;; can parse the output.
- (append (list "TERM=dumb" "LANGUAGE=C" "HGRCPATH=")
+ (append (list "TERM=dumb" "LANGUAGE=C")
process-environment)))
(process-file
"hg" nil t nil
+ "--config" "alias.status=status"
+ "--config" "defaults.status="
"status" "-A" (file-relative-name file)))
;; Some problem happened. E.g. We can't find an `hg'
;; executable.
@@ -199,7 +201,7 @@ If nil, use the value of `vc-diff-switches'. If t, use no switches."
((status nil)
(default-directory (file-name-directory file))
;; Avoid localization of messages so we can parse the output.
- (avoid-local-env (append (list "TERM=dumb" "LANGUAGE=C" "HGRCPATH=")
+ (avoid-local-env (append (list "TERM=dumb" "LANGUAGE=C")
process-environment))
(out
(with-output-to-string
@@ -211,6 +213,8 @@ If nil, use the value of `vc-diff-switches'. If t, use no switches."
;; Ignore all errors.
(process-file
"hg" nil t nil
+ "--config" "alias.parents=parents"
+ "--config" "defaults.parents="
"parents" "--template" "{rev}" (file-relative-name file)))
;; Some problem happened. E.g. We can't find an `hg'
;; executable.
diff --git a/lisp/calendar/appt.el b/lisp/calendar/appt.el
index ad36531bb40..ea419aee52d 100644
--- a/lisp/calendar/appt.el
+++ b/lisp/calendar/appt.el
@@ -48,8 +48,9 @@
;; package is activated. Additionally, the appointments list is
;; recreated automatically at 12:01am for those who do not logout
;; every day or are programming late. It is also updated when the
;; `diary-file' is saved. Calling `appt-check' with an argument (or
;; re-enabling the package) forces a re-initialization at any time.
;;
;; In order to add or delete items from today's list, without
;; changing the diary file, use `appt-add' and `appt-delete'.
@@ -262,7 +263,7 @@ The variable `appt-audible' controls the audible reminder."
"Check for an appointment and update any reminder display.
If optional argument FORCE is non-nil, reparse the diary file for
appointments. Otherwise the diary file is only parsed once per day,
-and when saved.
+or when it (or a file it includes) is saved.
Note: the time must be the first thing in the line in the diary
for a warning to be issued. The format of the time can be either
@@ -346,6 +347,8 @@ displayed in a window:
(if d-buff ; diary buffer exists
(with-current-buffer d-buff
diary-selective-display))))
+ ;; FIXME why not using diary-list-entries with
+ ;; non-nil LIST-ONLY?
(diary)
;; If the diary buffer existed before this command,
;; restore its display state. Otherwise, kill it.
@@ -643,8 +646,10 @@ hour and minute parts."
(defun appt-update-list ()
"If the current buffer is visiting the diary, update appointments.
-This function is intended for use with `write-file-functions'."
- (and (string-equal buffer-file-name (expand-file-name diary-file))
+This function also acts on any file listed in `diary-included-files'.
+It is intended for use with `write-file-functions'."
+ (and (member buffer-file-name (append diary-included-files
+ (list (expand-file-name diary-file))))
appt-timer
(let ((appt-display-diary nil))
(appt-check t)))
@@ -48,8 +48,9 @@
;; recreated automatically at 12:01am for those who do not logout
;; every day or are programming late. It is also updated when the
-;; `diary-file' is saved. Calling `appt-check' with an argument (or
-;; re-enabling the package) forces a re-initialization at any time.
+;; `diary-file' (or a file it includes) is saved. Calling
+;; `appt-check' with an argument (or re-enabling the package) forces a
+;; re-initialization at any time.
;;
;; In order to add or delete items from today's list, without